@@ -27,10 +27,10 @@
 
 // clang-format off
 #define ROCBLAS_VERSION_MAJOR       4
-#define ROCBLAS_VERSION_MINOR       0
+#define ROCBLAS_VERSION_MINOR       3
 #define ROCBLAS_VERSION_PATCH       0
 #define ROCBLAS_VERSION_TWEAK       
-#define ROCBLAS_VERSION_COMMIT_ID   
+#define ROCBLAS_TENSILE_COMMIT_ID   "" , ""
 // clang-format on
 
 #endif /* ROCBLAS_VERSION_H */
